@@ -1,8 +1,9 @@
 import os
 import pygsheets
 import pandas as pd
-from dotenv import load_dotenv
-load_dotenv()
+
+from .creds import load_creds
+load_creds()
 
 class Gsheets:
     """
@@ -19,7 +20,7 @@ class Gsheets:
         Spreadsheet is stored as env var
         Worksheet is passed in as plain text
         """        
-        ws = self.spreadsheet.worksheet_by_title(worksheet)
+        ws = self.client.open_by_key(self.spreadsheet).worksheet_by_title(worksheet)
         df = ws.get_as_df(start=start_cell, end=end_cell)
         print(f"{self.spreadsheet.title}.{worksheet}: Downloaded {df.shape} shape")
         return df
